@@ -26,6 +26,7 @@ OC.L10N.register(
     "For more information check the wiki." : "Pour plus d'informations, consultez le wiki.",
     "Update interval" : "Intervalle de mise à jour",
     "Interval in seconds in which the feeds will be updated." : "Fréquence à laquelle les flux seront mis à jour (en secondes).",
+    "For more information check the documentation." : "Pour plus d'informations, consulter la documentation",
     "Saved" : "Enregistré",
     "Download" : "Télécharger",
     "Close" : "Fermer",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "No users found" : "Aucun utilisateur trouvé",
     "Error while searching for users" : "Erreur lors de la recherche d'utilisateurs",
     "Share on social media" : "Partager sur les réseaux sociaux",
+    "I wanted you to see this article" : "Je souhaitais que vous lisiez cet article",
     "Check out this article" : "Consultez cet article",
     "by" : "par",
     "from" : "de",
@@ -84,6 +86,7 @@ OC.L10N.register(
     "Credentials" : "Informations d'identification",
     "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les informations d'identification HTTP Basic Auth doivent être stocké en clair ! Toute personne ayant accès au serveur ou à la base de données y aura accès !",
     "Password" : "Mot de passe",
+    "Auto discover Feed" : "Flux de découverte automatique",
     "New Folder" : "Nouveau dossier",
     "Create" : "Créer",
     "Explore" : "Explorer",
