@@ -5,10 +5,17 @@ OC.L10N.register(
     "Request unauthorized. Are you logged in?" : "Pedido não autorizado. Fez o login?",
     "Request forbidden. Are you an admin?" : "Pedido proibido. É um administrador?",
     "Token expired or app not enabled! Reload the page!" : "Token expirou ou aplicação não ativa! Recarregue a página!",
+    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Erro interno do servidor. Veja por favor o ficheiro na pasta data/nextcloud.log para mais informações!",
+    "Request failed, Nextcloud is in currently in maintenance mode!" : "Falha no pedido, Nextcloud está atualmente em modo de manutenção!",
+    "News feeds" : "Feeds de notícias",
     "Unread articles" : "Artigos não lidos",
+    "News" : "Notícias",
     "News folders" : "Novas pastas",
     "Shared with me" : "Partilhadas comigo",
-    "Purge interval" : "Intervalo de Purgar",
+    "An RSS/Atom feed reader" : "Leitor de feeds RSS/Atom",
+    "Use system cron for updates" : "Use o programador do sistema para as atualizações",
+    "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
+    "Purge interval" : "Intervalo de Purga",
     "Maximum read count per feed" : "Número máximo de leituras por feed",
     "Maximum redirects" : "Máximo de redirecionamentos",
     "Feed fetcher timeout" : "A obtenção do feed expirou",
